
# Class: NamingMixin


require either neurodata_type_def or name to be present

URI: [nwb_schema_language:NamingMixin](https://w3id.org/p2p_ld/nwb-schema-language/NamingMixin)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[Group]uses%20-.->[NamingMixin],[Dataset]uses%20-.->[NamingMixin],[Group],[Dataset])](https://yuml.me/diagram/nofunky;dir:TB/class/[Group]uses%20-.->[NamingMixin],[Dataset]uses%20-.->[NamingMixin],[Group],[Dataset])

## Mixin for

 * [Dataset](Dataset.md) (mixin) 
 * [Group](Group.md) (mixin) 

## Referenced by Class


## Attributes

